==> timezone-0.0.3.tgz: package/lib/timezone.js <==
(function() {
  var defintion;
  var __slice = Array.prototype.slice;
  defintion = function(exports) {
    var DAY, HOUR, LOCALES, MINUTE, SECOND, TIMEZONES, ch, dialHours, flag, format, isDate, isLeapYear, isoWeek, monthDayOfYear, offsetInMilliseconds, pad, padding, paddings, parse, specifiers, transforms, tz, wallclock, weekOfYear, _ref;
    TIMEZONES = {
      zones: {},
      rules: {}
    };
    LOCALES = {
      en_US: {
        day: {
          abbrev: "Sun Mon Tue Wed Thu Fri Sat".split(/\s/),
          full: "Sunday Monday Tuesday Wednesday Thursday Friday Saturday".split(/\s/)
        },
        month: {
          abbrev: "Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(/\s/),
          full: "January February March April May June July August September October November December".split(/\s/)
        },
        dateFormat: "%m/%d/%y",
        timeFormat: "%H:%M:%S",
        dateTimeFormat: "%a %b %_d %H:%M:%S %Y",
        meridiem: ["am", "pm"]
      }
    };
    SECOND = 1000;
    MINUTE = SECOND * 60;
    HOUR = MINUTE * 60;
    DAY = HOUR * 24;
    pad = function(number, padding, char) {
      var string;
      string = String(number);
      return "" + (new Array((padding - string.length) + 1).join(char)) + string;
    };
    monthDayOfYear = [1, 32, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335];
    isLeapYear = function(date) {
      var year;
      year = date.getUTCFullYear();
      if (year % 400 === 0) {
        return true;
      } else if (year % 100 === 0) {
        return false;
      } else if (year % 4 === 0) {
        return true;
      } else {
        return false;
      }
    };
    weekOfYear = function(date, startOfWeek) {
      var day, diff, nyd, remaining, utc, week, weekStart;
      utc = new Date(Date.UTC(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate()));
      nyd = new Date(Date.UTC(date.getUTCFullYear(), 0, 1));
      diff = (utc.getTime() - nyd.getTime()) / DAY;
      day = utc.getUTCDay();
      if (nyd.getUTCDay() === startOfWeek) {
        weekStart = 0;
      } else {
        weekStart = 7 - nyd.getUTCDay() + startOfWeek;
        if (weekStart === 8) {
          weekStart = 1;
        }
      }
      remaining = diff - weekStart;
      week = 0;
      if (diff >= weekStart) {
        week++;
        diff -= weekStart;
        week += Math.floor(diff / 7);
      }
      return week;
    };
    isoWeek = function(date) {
      var ny, nyd, offset, week;
      nyd = new Date(Date.UTC(date.getUTCFullYear(), 0, 1)).getUTCDay();
      offset = nyd > 1 && nyd <= 4 ? 1 : 0;
      week = weekOfYear(date, 1) + offset;
      if (week === 0) {
        ny = new Date(Date.UTC(date.getUTCFullYear() - 1, 0, 1));
        nyd = ny.getUTCDay();
        week = nyd === 4 || (nyd === 3 && isLeapYear(ny)) ? 53 : 52;
        return [week, date.getUTCFullYear() - 1];
      } else if (week === 53 && !(nyd === 4 || (nyd === 3 && isLeapYear(date)))) {
        return [1, date.getUTCFullYear() + 1];
      } else {
        return [week, date.getUTCFullYear()];
      }
    };
    dialHours = function(date) {
      var hours;
      hours = Math.floor(date.getUTCHours() % 12);
      if (hours === 0) {
        return 12;
      } else {
        return hours;
      }
    };
    specifiers = {
      a: function(date, locale) {
        return locale.day.abbrev[date.getUTCDay()];
      },
      A: function(date, locale) {
        return locale.day.full[date.getUTCDay()];
      },
      d: function(date) {
        return date.getUTCDate();
      },
      e: function(date) {
        return date.getUTCDate();
      },
      j: function(date) {
        var days, month;
        month = date.getUTCMonth();
        days = monthDayOfYear[month];
        if (month > 2 && isLeapYear(date)) {
          days++;
        }
        days += date.getUTCDate() - 1;
        return days;
      },
      u: function(date) {
        var day;
        day = date.getUTCDay();
        if (day === 0) {
          day = 7;
        }
        return day;
      },
      w: function(date) {
        return date.getUTCDay();
      },
      U: function(date) {
        return weekOfYear(date, 0);
      },
      W: function(date) {
        return weekOfYear(date, 1);
      },
      V: function(date) {
        var iso;
        return iso = isoWeek(date)[0];
      },
      G: function(date) {
        var iso;
        return iso = isoWeek(date)[1];
      },
      g: function(date) {
        var iso;
        return iso = isoWeek(date)[1] % 100;
      },
      m: function(date) {
        return date.getUTCMonth() + 1;
      },
      h: function(date, locale) {
        return locale.month.abbrev[date.getUTCMonth()];
      },
      b: function(date, locale) {
        return locale.month.abbrev[date.getUTCMonth()];
      },
      B: function(date, locale) {
        return locale.month.full[date.getUTCMonth()];
      },
      y: function(date) {
        return date.getUTCFullYear() % 100;
      },
      Y: function(date) {
        return date.getUTCFullYear();
      },
      C: function(date) {
        return Math.floor(date.getFullYear() / 100);
      },
      D: function(date) {
        return tz("%m/%d/%y", date);
      },
      x: function(date, locale) {
        return tz(locale.dateFormat, date, locale);
      },
      F: function(date) {
        return tz("%Y-%m-%d", date);
      },
      l: function(date) {
        return dialHours(date);
      },
      I: function(date) {
        return dialHours(date);
      },
      k: function(date) {
        return date.getUTCHours();
      },
      H: function(date) {
        return date.getUTCHours();
      },
      P: function(date, locale) {
        return locale.meridiem[Math.floor(date.getUTCHours() / 12)];
      },
      p: function(date, locale) {
        return locale.meridiem[Math.floor(date.getUTCHours() / 12)].toUpperCase();
      },
      M: function(date) {
        return date.getUTCMinutes();
      },
      s: function(date) {
        return Math.floor(date.getTime() / 1000);
      },
      S: function(date) {
        return date.getUTCSeconds();
      },
      N: function(date) {
        return (date.getTime() % 1000) * 1000000;
      },
      r: function(date) {
        return tz("%I:%M:%S %p", date);
      },
      R: function(date) {
        return tz("%H:%M", date);
      },
      T: function(date) {
        return tz("%H:%M:%S", date);
      },
      X: function(date, locale) {
        return tz(locale.timeFormat, date, locale);
      },
      c: function(date, locale) {
        return tz(locale.dateTimeFormat, date, locale);
      },
      z: function(date, locale, tzdata) {
        var offset;
        offset = Math.floor(offsetInMilliseconds(tzdata.offset) / 1000 / 60);
        if (offset < 0) {
          return "-" + (pad(Math.abs(offset), 4, "0"));
        } else {
          return pad(Math.abs(offset), 4, "0");
        }
      }
    };
    padding = {
      d: 2,
      U: 2,
      W: 2,
      V: 2,
      g: 2,
      m: 2,
      j: 3,
      C: 2,
      I: 2,
      H: 2,
      k: 2,
      M: 2,
      S: 2,
      N: 9,
      y: 2
    };
    paddings = {
      "-": function(number) {
        return number;
      }
    };
    _ref = {
      "_": " ",
      "0": "0"
    };
    for (flag in _ref) {
      ch = _ref[flag];
      paddings[flag] = (function(ch) {
        return function(number, padding) {
          return pad(number, padding, ch);
        };
      })(ch);
    }
    transforms = {
      none: function(value) {
        return value;
      },
      "^": function(value) {
        return value.toUpperCase();
      }
    };
    format = function(date, request) {
      var flags, i, locale, match, offset, output, prefix, rest, specifier, transform, tzdata, value, zone, _ref2, _ref3, _ref4, _ref5;
      format = request.format, locale = request.locale, zone = request.zone;
      _ref2 = [new Date(date), []], offset = _ref2[0], output = _ref2[1];
      tzdata = TIMEZONES.zones[zone];
      if (zone !== "UTC") {
        offset = wallclock(offset, tzdata);
      }
      while (format.length) {
        match = /^(.*?)%([-0_^]?)([aAcdDeFHIjklMNpPsrRSTuwXUWVmhbByYcGgCx])(.*)$/.exec(format);
        if (match) {
          _ref3 = match.slice(1), prefix = _ref3[0], flags = _ref3[1], specifier = _ref3[2], rest = _ref3[3];
          value = specifiers[specifier](offset, locale);
          if (padding[specifier]) {
            flag = specifier === "k" ? "_" : "0";
            for (i = 0, _ref4 = flags.length; 0 <= _ref4 ? i < _ref4 : i > _ref4; 0 <= _ref4 ? i++ : i--) {
              if (paddings[flags[i]]) {
                flag = flags[i];
              }
            }
            value = paddings[flag](value, padding[specifier], tzdata);
          }
          transform = transforms.none;
          for (i = 0, _ref5 = flags.length; 0 <= _ref5 ? i <= _ref5 : i >= _ref5; 0 <= _ref5 ? i++ : i--) {
            transform = transforms[flags[i]] || transform;
          }
          value = transform(value);
          if (prefix != null) {
            output.push(prefix);
          }
          output.push(value);
          format = rest;
        } else if (format.length) {
          output.push(format);
          format = "";
        }
      }
      return output.join("");
    };
    isDate = function(object) {};
    parse = function(pattern) {};
    offsetInMilliseconds = function(pattern) {
      var hours, match, minutes, offset, seconds, sign, _ref2;
      match = /^(-?)(\d)+:(\d)+(?::(\d+))?$/.exec(pattern).slice(1);
      sign = match.shift();
      _ref2 = match.map(function(number) {
        return parseInt(number, 10);
      }), hours = _ref2[0], minutes = _ref2[1], seconds = _ref2[2];
      offset = hours * HOUR;
      offset += minutes * MINUTE;
      offset += (seconds || 0) * SECOND;
      if (sign === '-') {
        offset *= -1;
      }
      console.log(offset, pattern);
      return offset;
    };
    ({
      compare: function() {
        var difference, field, fields, left, right, _i, _len;
        left = arguments[0], right = arguments[1], fields = 3 <= arguments.length ? __slice.call(arguments, 2) : [];
        for (_i = 0, _len = fields.length; _i < _len; _i++) {
          field = fields[_i];
          field = field.replace(/^./, function(m) {
            return "getUTC" + (m.toUpperCase());
          });
          difference = left[field]() - right[field]();
          if (!difference) {
            return difference;
          }
        }
      }
    });
    wallclock = function(date, tzdata) {
      var adjusted, adjustment, candidate, i, parsed, time, _ref2;
      time = date.getTime();
      for (i = _ref2 = tzdata.length - 1; _ref2 <= 0 ? i <= 0 : i >= 0; _ref2 <= 0 ? i++ : i--) {
        candidate = tzdata[i];
        adjustment = time + offsetInMilliseconds(candidate.offset);
        console.log(time, adjustment, new Date(time).toUTCString(), new Date(adjustment).toUTCString());
        if (candidate.until) {
          parsed = new Date(candidate.until);
          if (parsed.getTime() < adjustment) {
            break;
          }
        }
        adjusted = adjustment;
      }
      return new Date(adjusted);
    };
    exports.tz = tz = function() {
      var adjustment, argument, date, request, splat, _i, _j, _len, _len2, _ref2;
      date = arguments[0], splat = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      if (!(date != null)) {
        throw new Error("invalid arguments");
      }
      request = {
        zone: "UTC",
        adjustments: []
      };
      if (typeof date === "string" && date.indexOf("%") !== -1) {
        request.format = date;
        date = splat.shift();
      } else {
        for (_i = 0, _len = splat.length; _i < _len; _i++) {
          argument = splat[_i];
          argument = String(argument);
          if (argument.indexOf("%") !== -1) {
            request.format || (request.format = argument);
          } else if (TIMEZONES.zones[argument]) {
            request.zone || (request.zone = argument);
          } else if (/^\w{2}_\w+{2}$/.test(argument)) {
            request.locale || (request.locale = LOCALES[argument]);
            if (!request.locale) {
              throw new Error("unknown locale");
            }
          } else {
            request.adjustments.push(argument);
          }
        }
      }
      request.locale || (request.locale = LOCALES.en_US);
      if (date.getTime) {
        date = date.getTime();
      } else if (typeof date === "string") {
        date = parse(date, request);
      }
      _ref2 = request.adjustments;
      for (_j = 0, _len2 = _ref2.length; _j < _len2; _j++) {
        adjustment = _ref2[_j];
        date = adjust(adjustment, request);
      }
      if (request.format) {
        return format(date, request);
      } else {
        return date;
      }
    };
    tz.locales = function(override) {
      var k, v;
      if (override != null) {
        for (k in override) {
          v = override[k];
          LOCALES[k] = v;
        }
      }
      return LOCALES;
    };
    return tz.timezones = function(override) {
      var k, v, _ref2, _ref3;
      if (override != null) {
        _ref2 = override != null ? override.zones : void 0;
        for (k in _ref2) {
          v = _ref2[k];
          TIMEZONES.zones[k] = v;
        }
        _ref3 = override != null ? override.rules : void 0;
        for (k in _ref3) {
          v = _ref3[k];
          TIMEZONES.rules[k] = v;
        }
      }
      return TIMEZONES;
    };
  };
  if ((typeof module !== "undefined" && module !== null) && (module.exports != null)) {
    defintion(module.exports);
  } else {
    defintion(this);
  }
}).call(this);

==> timezone-0.0.5.tgz: package/lib/timezone.js <==
(function() {
  var defintion;
  var __slice = Array.prototype.slice;
  defintion = function(exports) {
    var DAY, HOUR, LOCALES, MINUTE, SECOND, TIMEZONES, ch, dialHours, flag, isDate, isLeapYear, isoWeek, monthDayOfYear, offsetInMilliseconds, pad, padding, paddings, parse, specifiers, toString, transforms, tz, wallclock, weekOfYear, _ref;
    TIMEZONES = {
      zones: {},
      rules: {}
    };
    LOCALES = {
      en_US: {
        day: {
          abbrev: "Sun Mon Tue Wed Thu Fri Sat".split(/\s/),
          full: "Sunday Monday Tuesday Wednesday Thursday Friday Saturday".split(/\s/)
        },
        month: {
          abbrev: "Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(/\s/),
          full: "January February March April May June July August September October November December".split(/\s/)
        },
        dateFormat: "%m/%d/%y",
        timeFormat: "%H:%M:%S",
        dateTimeFormat: "%a %b %_d %H:%M:%S %Y",
        meridiem: ["am", "pm"]
      }
    };
    SECOND = 1000;
    MINUTE = SECOND * 60;
    HOUR = MINUTE * 60;
    DAY = HOUR * 24;
    pad = function(number, padding, char) {
      var string;
      string = String(number);
      return "" + (new Array((padding - string.length) + 1).join(char)) + string;
    };
    monthDayOfYear = [1, 32, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335];
    isLeapYear = function(date) {
      var year;
      year = date.getUTCFullYear();
      if (year % 400 === 0) {
        return true;
      } else if (year % 100 === 0) {
        return false;
      } else if (year % 4 === 0) {
        return true;
      } else {
        return false;
      }
    };
    weekOfYear = function(date, startOfWeek) {
      var day, diff, nyd, remaining, utc, week, weekStart;
      utc = new Date(Date.UTC(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate()));
      nyd = new Date(Date.UTC(date.getUTCFullYear(), 0, 1));
      diff = (utc.getTime() - nyd.getTime()) / DAY;
      day = utc.getUTCDay();
      if (nyd.getUTCDay() === startOfWeek) {
        weekStart = 0;
      } else {
        weekStart = 7 - nyd.getUTCDay() + startOfWeek;
        if (weekStart === 8) {
          weekStart = 1;
        }
      }
      remaining = diff - weekStart;
      week = 0;
      if (diff >= weekStart) {
        week++;
        diff -= weekStart;
        week += Math.floor(diff / 7);
      }
      return week;
    };
    isoWeek = function(date) {
      var ny, nyd, offset, week;
      nyd = new Date(Date.UTC(date.getUTCFullYear(), 0, 1)).getUTCDay();
      offset = nyd > 1 && nyd <= 4 ? 1 : 0;
      week = weekOfYear(date, 1) + offset;
      if (week === 0) {
        ny = new Date(Date.UTC(date.getUTCFullYear() - 1, 0, 1));
        nyd = ny.getUTCDay();
        week = nyd === 4 || (nyd === 3 && isLeapYear(ny)) ? 53 : 52;
        return [week, date.getUTCFullYear() - 1];
      } else if (week === 53 && !(nyd === 4 || (nyd === 3 && isLeapYear(date)))) {
        return [1, date.getUTCFullYear() + 1];
      } else {
        return [week, date.getUTCFullYear()];
      }
    };
    dialHours = function(date) {
      var hours;
      hours = Math.floor(date.getUTCHours() % 12);
      if (hours === 0) {
        return 12;
      } else {
        return hours;
      }
    };
    specifiers = {
      a: function(date, locale) {
        return locale.day.abbrev[date.getUTCDay()];
      },
      A: function(date, locale) {
        return locale.day.full[date.getUTCDay()];
      },
      d: function(date) {
        return date.getUTCDate();
      },
      e: function(date) {
        return date.getUTCDate();
      },
      j: function(date) {
        var days, month;
        month = date.getUTCMonth();
        days = monthDayOfYear[month];
        if (month > 2 && isLeapYear(date)) {
          days++;
        }
        days += date.getUTCDate() - 1;
        return days;
      },
      u: function(date) {
        var day;
        day = date.getUTCDay();
        if (day === 0) {
          day = 7;
        }
        return day;
      },
      w: function(date) {
        return date.getUTCDay();
      },
      U: function(date) {
        return weekOfYear(date, 0);
      },
      W: function(date) {
        return weekOfYear(date, 1);
      },
      V: function(date) {
        var iso;
        return iso = isoWeek(date)[0];
      },
      G: function(date) {
        var iso;
        return iso = isoWeek(date)[1];
      },
      g: function(date) {
        var iso;
        return iso = isoWeek(date)[1] % 100;
      },
      m: function(date) {
        return date.getUTCMonth() + 1;
      },
      h: function(date, locale) {
        return locale.month.abbrev[date.getUTCMonth()];
      },
      b: function(date, locale) {
        return locale.month.abbrev[date.getUTCMonth()];
      },
      B: function(date, locale) {
        return locale.month.full[date.getUTCMonth()];
      },
      y: function(date) {
        return date.getUTCFullYear() % 100;
      },
      Y: function(date) {
        return date.getUTCFullYear();
      },
      C: function(date) {
        return Math.floor(date.getFullYear() / 100);
      },
      D: function(date) {
        return tz("%m/%d/%y", date);
      },
      x: function(date, locale) {
        return tz(locale.dateFormat, date, locale);
      },
      F: function(date) {
        return tz("%Y-%m-%d", date);
      },
      l: function(date) {
        return dialHours(date);
      },
      I: function(date) {
        return dialHours(date);
      },
      k: function(date) {
        return date.getUTCHours();
      },
      H: function(date) {
        return date.getUTCHours();
      },
      P: function(date, locale) {
        return locale.meridiem[Math.floor(date.getUTCHours() / 12)];
      },
      p: function(date, locale) {
        return locale.meridiem[Math.floor(date.getUTCHours() / 12)].toUpperCase();
      },
      M: function(date) {
        return date.getUTCMinutes();
      },
      s: function(date) {
        return Math.floor(date.getTime() / 1000);
      },
      S: function(date) {
        return date.getUTCSeconds();
      },
      N: function(date) {
        return (date.getTime() % 1000) * 1000000;
      },
      r: function(date) {
        return tz("%I:%M:%S %p", date);
      },
      R: function(date) {
        return tz("%H:%M", date);
      },
      T: function(date) {
        return tz("%H:%M:%S", date);
      },
      X: function(date, locale) {
        return tz(locale.timeFormat, date, locale);
      },
      c: function(date, locale) {
        return tz(locale.dateTimeFormat, date, locale);
      },
      z: function(date, locale, tzdata) {
        var offset;
        offset = Math.floor(offsetInMilliseconds(tzdata.offset) / 1000 / 60);
        if (offset < 0) {
          return "-" + (pad(Math.abs(offset), 4, "0"));
        } else {
          return pad(Math.abs(offset), 4, "0");
        }
      }
    };
    padding = {
      d: 2,
      U: 2,
      W: 2,
      V: 2,
      g: 2,
      m: 2,
      j: 3,
      C: 2,
      I: 2,
      H: 2,
      k: 2,
      M: 2,
      S: 2,
      N: 9,
      y: 2
    };
    paddings = {
      "-": function(number) {
        return number;
      }
    };
    _ref = {
      "_": " ",
      "0": "0"
    };
    for (flag in _ref) {
      ch = _ref[flag];
      paddings[flag] = (function(ch) {
        return function(number, padding) {
          return pad(number, padding, ch);
        };
      })(ch);
    }
    transforms = {
      none: function(value) {
        return value;
      },
      "^": function(value) {
        return value.toUpperCase();
      }
    };
    toString = function(date, request) {
      var flags, format, i, locale, match, offset, output, prefix, rest, specifier, transform, tzdata, value, zone, _ref2, _ref3, _ref4, _ref5;
      format = request.format, locale = request.locale, zone = request.zone;
      _ref2 = [new Date(date), []], offset = _ref2[0], output = _ref2[1];
      tzdata = TIMEZONES.zones[zone];
      if (zone !== "UTC") {
        offset = wallclock(offset, tzdata);
      }
      while (format.length) {
        match = /^(.*?)%([-0_^]?)([aAcdDeFHIjklMNpPsrRSTuwXUWVmhbByYcGgCx])(.*)$/.exec(format);
        if (match) {
          _ref3 = match.slice(1), prefix = _ref3[0], flags = _ref3[1], specifier = _ref3[2], rest = _ref3[3];
          value = specifiers[specifier](offset, locale);
          if (padding[specifier]) {
            flag = specifier === "k" ? "_" : "0";
            for (i = 0, _ref4 = flags.length; 0 <= _ref4 ? i < _ref4 : i > _ref4; 0 <= _ref4 ? i++ : i--) {
              if (paddings[flags[i]]) {
                flag = flags[i];
              }
            }
            value = paddings[flag](value, padding[specifier], tzdata);
          }
          transform = transforms.none;
          for (i = 0, _ref5 = flags.length; 0 <= _ref5 ? i <= _ref5 : i >= _ref5; 0 <= _ref5 ? i++ : i--) {
            transform = transforms[flags[i]] || transform;
          }
          value = transform(value);
          if (prefix != null) {
            output.push(prefix);
          }
          output.push(value);
          format = rest;
        } else if (format.length) {
          output.push(format);
          format = "";
        }
      }
      return output.join("");
    };
    isDate = function(object) {};
    parse = function(pattern) {};
    offsetInMilliseconds = function(pattern) {
      var hours, match, minutes, offset, seconds, sign, _ref2;
      match = /^(-?)(\d)+:(\d)+(?::(\d+))?$/.exec(pattern).slice(1);
      sign = match.shift();
      _ref2 = match.map(function(number) {
        return parseInt(number, 10);
      }), hours = _ref2[0], minutes = _ref2[1], seconds = _ref2[2];
      offset = hours * HOUR;
      offset += minutes * MINUTE;
      offset += (seconds || 0) * SECOND;
      if (sign === '-') {
        offset *= -1;
      }
      console.log(offset, pattern);
      return offset;
    };
    ({
      compare: function() {
        var difference, field, fields, left, right, _i, _len;
        left = arguments[0], right = arguments[1], fields = 3 <= arguments.length ? __slice.call(arguments, 2) : [];
        for (_i = 0, _len = fields.length; _i < _len; _i++) {
          field = fields[_i];
          field = field.replace(/^./, function(m) {
            return "getUTC" + (m.toUpperCase());
          });
          difference = left[field]() - right[field]();
          if (!difference) {
            return difference;
          }
        }
      }
    });
    wallclock = function(date, tzdata) {
      var adjusted, adjustment, candidate, i, parsed, time, _ref2;
      time = date.getTime();
      for (i = _ref2 = tzdata.length - 1; _ref2 <= 0 ? i <= 0 : i >= 0; _ref2 <= 0 ? i++ : i--) {
        candidate = tzdata[i];
        adjustment = time + offsetInMilliseconds(candidate.offset);
        console.log(time, adjustment, new Date(time).toUTCString(), new Date(adjustment).toUTCString());
        if (candidate.until) {
          parsed = new Date(candidate.until);
          if (parsed.getTime() < adjustment) {
            break;
          }
        }
        adjusted = adjustment;
      }
      return new Date(adjusted);
    };
    exports.tz = tz = function() {
      var adjustment, argument, date, request, splat, _i, _j, _len, _len2, _ref2;
      date = arguments[0], splat = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
      if (!(date != null)) {
        throw new Error("invalid arguments");
      }
      request = {
        zone: "UTC",
        adjustments: []
      };
      if (typeof date === "string" && date.indexOf("%") !== -1) {
        request.format = date;
        date = splat.shift();
      } else {
        for (_i = 0, _len = splat.length; _i < _len; _i++) {
          argument = splat[_i];
          argument = String(argument);
          if (argument.indexOf("%") !== -1) {
            request.format || (request.format = argument);
          } else if (TIMEZONES.zones[argument]) {
            request.zone || (request.zone = argument);
          } else if (/^\w{2}_\w+{2}$/.test(argument)) {
            request.locale || (request.locale = LOCALES[argument]);
            if (!request.locale) {
              throw new Error("unknown locale");
            }
          } else {
            request.adjustments.push(argument);
          }
        }
      }
      request.locale || (request.locale = LOCALES.en_US);
      if (date.getTime) {
        date = date.getTime();
      } else if (typeof date === "string") {
        date = parse(date, request);
      }
      _ref2 = request.adjustments;
      for (_j = 0, _len2 = _ref2.length; _j < _len2; _j++) {
        adjustment = _ref2[_j];
        date = adjust(adjustment, request);
      }
      if (request.format) {
        return toString(date, request);
      } else {
        return date;
      }
    };
    tz.locales = function(override) {
      var k, v;
      if (override != null) {
        for (k in override) {
          v = override[k];
          LOCALES[k] = v;
        }
      }
      return LOCALES;
    };
    return tz.timezones = function(override) {
      var k, v, _ref2, _ref3;
      if (override != null) {
        _ref2 = override != null ? override.zones : void 0;
        for (k in _ref2) {
          v = _ref2[k];
          TIMEZONES.zones[k] = v;
        }
        _ref3 = override != null ? override.rules : void 0;
        for (k in _ref3) {
          v = _ref3[k];
          TIMEZONES.rules[k] = v;
        }
      }
      return TIMEZONES;
    };
  };
  if ((typeof module !== "undefined" && module !== null) && (module.exports != null)) {
    defintion(module.exports);
  } else {
    defintion(this);
  }
}).call(this);
